@@ -22,17 +22,16 @@ from __future__ import annotations
 
 import contextvars
 from dataclasses import dataclass, field
-from typing import Any, Callable, Dict, Iterator, List, Optional, Set, Type, Tuple
-
+from typing import Any, Callable, Dict, Iterator, List, Optional, Set, Tuple, Type
 
 # ============================================================
 # THREAD-LOCAL CONTEXT
 # ============================================================
 
-_activation_ctx: contextvars.ContextVar = contextvars.ContextVar(
+_activation_ctx: contextvars.ContextVar[Dict[Any, bool] | None] = contextvars.ContextVar(
     "smartswitch_activation", default=None
 )
-_runtime_ctx: contextvars.ContextVar = contextvars.ContextVar(
+_runtime_ctx: contextvars.ContextVar[Dict[Any, Dict[str, Any]] | None] = contextvars.ContextVar(
     "smartswitch_runtime", default=None
 )
 
@@ -59,14 +58,15 @@ def _get_runtime_map() -> Dict[Any, Dict[str, Any]]:
 # DATA STRUCTURES
 # ============================================================
 
+
 @dataclass
 class MethodEntry:
     """Metadata and runtime info for a decorated method."""
 
-    name: str                       # logical registered name
-    func: Callable                  # original function
-    switch: "Switcher"         # owning switch
-    plugins: List[str]              # ordered plugin names
+    name: str  # logical registered name
+    func: Callable  # original function
+    switch: "Switcher"  # owning switch
+    plugins: List[str]  # ordered plugin names
     metadata: Dict[str, Any] = field(default_factory=dict)
 
 
@@ -92,6 +92,7 @@ class _PluginSpec:
 # PLUGIN BASE
 # ============================================================
 
+
 class BasePlugin:
     """
     Base class for Switcher plugins.
@@ -172,6 +173,7 @@ class BasePlugin:
 # SWITCH CALL PROXY
 # ============================================================
 
+
 class _SwitchCall:
     """
     A proxy object returned by Switcher when called with a string.
@@ -198,6 +200,7 @@ class _SwitchCall:
 # SMART SWITCH
 # ============================================================
 
+
 class Switcher:
     """
     Switcher is a decorator + dispatcher + plugin container.
@@ -247,6 +250,7 @@ class Switcher:
         inherit_plugins: Optional[bool] = None,
     ):
         self.name = name
+        self.prefix: str
         if prefix is None:
             self.prefix = parent.prefix if parent is not None else ""
         else:
@@ -257,9 +261,7 @@ class Switcher:
         self._local_plugin_specs: List[_PluginSpec] = []
         self._inherited_plugins: List[BasePlugin] = []
         self._inherited_plugin_specs: List[_PluginSpec] = []
-        self._inherit_plugins: bool = (
-            True if inherit_plugins is None else bool(inherit_plugins)
-        )
+        self._inherit_plugins: bool = True if inherit_plugins is None else bool(inherit_plugins)
         self._using_parent_plugins: bool = False
         self._children: Dict[str, "Switcher"] = {}
         self._methods: Dict[str, MethodEntry] = {}
@@ -297,7 +299,9 @@ class Switcher:
         except KeyError:
             raise KeyError(f"No child switch named {name!r} in {self!r}")
 
-    def _attach_child_switcher(self, child: "Switcher", explicit_name: Optional[str] = None) -> None:
+    def _attach_child_switcher(
+        self, child: "Switcher", explicit_name: Optional[str] = None
+    ) -> None:
         """Attach an actual Switcher instance as a child."""
         if child is self:
             raise ValueError("Cannot attach a switch to itself")
@@ -481,7 +485,7 @@ class Switcher:
         if alias:
             name = alias
         elif self.prefix and func_name.startswith(self.prefix):
-            name = func_name[len(self.prefix):]
+            name = func_name[len(self.prefix) :]
         else:
             name = func_name
         if name in self._methods:
